.grid .load-indicator {
  width: 100%;
  height: 100%;
  z-index: 900;
  background-color: #ffffff;
  display: table;
}
.grid .load-indicator .spinner {
  display: table-cell;
  vertical-align: middle;
  text-align: center;
}
.grid .load-indicator .spinner p {
  font-weight: 300;
  margin-top: 10px;
}
.grid .clickable {
  cursor: pointer;
}
.grid .builder-tag {
  margin-right: 0.3em;
  margin-left: 0.3em;
  cursor: pointer;
}
.grid .form-inline label {
  padding-left: 0.5em;
  padding-right: 0.5em;
}


/*# sourceMappingURL=styles.css.map*/